---
name: Feature request
about: Some functionality needs to be added…
title: ''
labels: feature
assignees: ''

---

What you're looking for might already be possible as a combination of existing functions, so these requests might get converted into requests for documentation (with a corresponding change in title).

Here are some links to documentation, to help you in your search.

   * [The tutorials site](https://uproot.readthedocs.io/)
   * [StackOverflow: [uproot] tag](https://stackoverflow.com/questions/tagged/uproot)
   * [Gitter: Scikit-HEP/uproot room](https://gitter.im/Scikit-HEP/uproot)
